# optoConfig-96 - Interactive configuration of experiments using the optoPlate-96


## Documentation

optoConfig-96 lives on [GitHub](https://github.com/WeberSynBioLab/optoConfig-96/). You will find further instructions and documentation over there!

If optoConfig-96 was useful to you, please consider citing the paper:

Thomas, OS, Hörner, M & Weber, W: A graphical user interface to design high-throughput optogenetic experiments with the optoPlate-96. *Nat Protoc* (2020). https://doi.org/10.1038/s41596-020-0349-x
